@@ -3,22 +3,6 @@
 This file defines the proksee-batch command-line interface and implements the
 high-level logic of the tool.
 
-The output directory will be structured as in the following example:
-
-    output_directory/
-        cgview-js_code/
-            ...
-        data/
-            genome_name_1.js
-            genome_name_2.js
-            ...
-        images/
-            genome_name_1.svg
-            genome_name_2.svg
-            ...
-        report.html
-
-
 """
 import json
 import os
@@ -35,14 +19,17 @@ import click
 import toml
 
 from .download_example_input import download_example_input
-from .genbank_to_cgview_json import genbank_to_cgview_json
 
 # from .generate_proksee_link import generate_proksee_link
 from .generate_report_html import generate_report_html
-from .get_stats_from_genbank import get_stats_from_genbank
+from .get_stats_from_seq_file import get_stats_from_seq_file
 from .merge_cgview_json_with_template import merge_cgview_json_with_template
 from .parse_additional_features import add_bed_features_and_tracks
 from .parse_additional_features import add_blast_features_and_tracks
+from .parse_additional_features import add_gff_features_and_tracks
+from .parse_additional_features import add_vcf_features_and_tracks
+from .seq_file_to_cgview_json import fasta_to_cgview_json
+from .seq_file_to_cgview_json import genbank_to_cgview_json
 
 # from .scrape_proksee_image import scrape_proksee_image
 from .validate_input_data import get_data_files
@@ -50,7 +37,7 @@ from .validate_input_data import validate_input_directory_contents
 
 
 @click.command()
-@click.version_option(version=version("proksee-batch"), prog_name="Proksee Batch")
+@click.version_option()
 @click.option(
     "--input",
     type=click.Path(exists=True, file_okay=False, dir_okay=True),
@@ -71,7 +58,9 @@ def main(
     output: Optional[str],
     download_example_data: Optional[str],
 ) -> None:
-    """Proksee Batch: A tool for visualizing batches of genomes via https://www.proksee.ca."""
+    """
+    Proksee Batch: A tool for visualizing batches of genomes via https://www.proksee.ca.
+    """
 
     # Check if the download example GenBank files option is used
     if download_example_data:
@@ -85,9 +74,10 @@ def main(
     if not input:
         handle_error_exit("Missing option '--input'.")
     else:
+        assert input is not None
         if not os.path.exists(input):
             handle_error_exit(f"The input directory does not exist: {input}")
-    input_dir_path = os.path.abspath(input)
+        input_dir_path = os.path.abspath(input)
 
     # Validate the contents of the input directory.
     validate_input_directory_contents(input_dir_path)
@@ -122,34 +112,67 @@ def main(
         os.mkdir(temp_output)
 
         # Get the data file paths
-        genbank_path = get_data_files(
+        genbank_paths = get_data_files(
             os.path.join(input_dir_path, genome_dir), "genbank"
-        )[0]
+        )
+        fasta_paths = get_data_files(os.path.join(input_dir_path, genome_dir), "fasta")
         json_paths = get_data_files(os.path.join(input_dir_path, genome_dir), "json")
         blast_paths = get_data_files(os.path.join(input_dir_path, genome_dir), "blast")
         bed_paths = get_data_files(os.path.join(input_dir_path, genome_dir), "bed")
         vcf_paths = get_data_files(os.path.join(input_dir_path, genome_dir), "vcf")
         gff_paths = get_data_files(os.path.join(input_dir_path, genome_dir), "gff")
 
-        # Get basic stats from the GenBank file.
-        (
-            genbank_description,
-            genbank_total_size,
-            genbank_number_of_contigs,
-            genbank_gc_content,
-        ) = get_stats_from_genbank(genbank_path)
-
-        genome_info[genome_code_name] = {
-            "Name": genome_dir,
-            "Description": genbank_description,
-            "Total size": genbank_total_size,
-            "Number of contigs": genbank_number_of_contigs,
-            "GC content": genbank_gc_content,
-        }
-
-        # Convert the GenBank file to a basic cgview map in JSON format.
+        # Define path to the basic cgview map in JSON format.
         basic_json_file = os.path.join(temp_output, genome_code_name + ".json")
-        genbank_to_cgview_json(genome_dir, genbank_path, basic_json_file)
+
+        if genbank_paths:
+            genbank_path = genbank_paths[0]
+
+            # Get basic stats from the GenBank file.
+            (
+                genbank_description,
+                genbank_total_size,
+                genbank_number_of_contigs,
+                genbank_gc_content,
+            ) = get_stats_from_seq_file(genbank_path, "genbank")
+
+            genome_info[genome_code_name] = {
+                "Name": genome_dir,
+                "Description": genbank_description,
+                "Total size": genbank_total_size,
+                "Number of contigs": genbank_number_of_contigs,
+                "GC content": genbank_gc_content,
+            }
+
+            # Convert the GenBank file to a basic cgview map in JSON format.
+            genbank_to_cgview_json(genome_dir, genbank_path, basic_json_file)
+
+        elif fasta_paths:
+            fasta_path = fasta_paths[0]
+
+            # Get basic stats from the FASTA file.
+            (
+                fasta_description,
+                fasta_total_size,
+                fasta_number_of_contigs,
+                fasta_gc_content,
+            ) = get_stats_from_seq_file(fasta_path, "fasta")
+
+            genome_info[genome_code_name] = {
+                "Name": genome_dir,
+                "Description": fasta_description,
+                "Total size": fasta_total_size,
+                "Number of contigs": fasta_number_of_contigs,
+                "GC content": fasta_gc_content,
+            }
+
+            # Convert the FASTA file to a basic cgview map in JSON format.
+            fasta_to_cgview_json(genome_dir, fasta_path, basic_json_file)
+
+        else:
+            handle_error_exit(
+                f"Could not find a GenBank or FASTA file in the {genome_dir} directory."
+            )
 
         # Parse the BLAST result files (if any) to create additional features and tracks.
         basic_json_file_with_blast_features = os.path.join(
@@ -178,6 +201,38 @@ def main(
                 basic_json_file_with_bed_features,
             )
 
+        # Parse the VCF files (if any) to create additional features and tracks.
+        basic_json_file_with_vcf_features = os.path.join(
+            temp_output, genome_code_name + ".with_vcf_features.json"
+        )
+        if vcf_paths:
+            add_vcf_features_and_tracks(
+                vcf_paths,
+                basic_json_file_with_bed_features,
+                basic_json_file_with_vcf_features,
+            )
+        else:
+            shutil.copy(
+                basic_json_file_with_bed_features,
+                basic_json_file_with_vcf_features,
+            )
+
+        # Parse the GFF files (if any) to create additional features and tracks.
+        basic_json_file_with_gff_features = os.path.join(
+            temp_output, genome_code_name + ".with_gff_features.json"
+        )
+        if gff_paths:
+            add_gff_features_and_tracks(
+                gff_paths,
+                basic_json_file_with_vcf_features,
+                basic_json_file_with_gff_features,
+            )
+        else:
+            shutil.copy(
+                basic_json_file_with_vcf_features,
+                basic_json_file_with_gff_features,
+            )
+
         # Determine path to the template Proksee configuration file.
         template_path = ""
         if json_paths:
@@ -199,15 +254,45 @@ def main(
         # Merge the basic cgview map with the template Proksee configuration file.
         merged_json_file = os.path.join(temp_output, genome_code_name + ".merged.json")
         merge_cgview_json_with_template(
-            basic_json_file_with_bed_features, template_path, merged_json_file
+            basic_json_file_with_gff_features, template_path, merged_json_file
         )
 
+        # Add GC content and GC skew tracks to the merged JSON.
+        merged_json_file_with_gc_tracks = os.path.join(
+            temp_output, genome_code_name + ".merged_with_gc_tracks.json"
+        )
+        with open(merged_json_file) as merged_json_fh, open(
+            merged_json_file_with_gc_tracks, "w"
+        ) as merged_json_file_with_gc_tracks_fh:
+            merged_json = json.load(merged_json_fh)
+            merged_json["cgview"]["tracks"].extend(
+                [
+                    {
+                        "name": "CG Content",
+                        "thicknessRatio": 2,
+                        "position": "inside",
+                        "dataType": "plot",
+                        "dataMethod": "sequence",
+                        "dataKeys": "gc-content",
+                    },
+                    {
+                        "name": "CG Skew",
+                        "thicknessRatio": 2,
+                        "position": "inside",
+                        "dataType": "plot",
+                        "dataMethod": "sequence",
+                        "dataKeys": "gc-skew",
+                    },
+                ]
+            )
+            json.dump(merged_json, merged_json_file_with_gc_tracks_fh)
+
         # Convert the merged JSON file to .js file by wrapping it in a variable assignment.
         js_file = os.path.join(output_path, "data", genome_code_name + ".js")
         with open(js_file, "w") as file:
             # Get the JSON data from the merged JSON file as a string.
             json_data = None
-            with open(merged_json_file) as json_file:
+            with open(merged_json_file_with_gc_tracks) as json_file:
                 json_data = json_file.read()
             # Write the variable assignment.
             file.write(f"json = {json_data};")
