@@ -1,3 +1,19 @@
+"""Code for generating an HTML report file with a table containing links to
+Proksee projects and images for each sample. A single genome viewer is
+positioned to the right of the table.
+
+The output directory will be structured as in the following example:
+
+    output_directory/
+        cgview-js_code/
+            ...
+        data/
+            genome_name_1.js
+            genome_name_2.js
+            ...
+        report.html
+"""
+
 import os
 from typing import Any
 from typing import Dict
@@ -111,6 +127,11 @@ def generate_report_html(output_dir: str, genome_info: Dict[str, Any]) -> None:
         cursor: pointer;
       }
 
+      .btn-toggle-legend,
+      #btn-toggle-legend {
+        content: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 30 30'%3E%3Ccircle cx='5' cy='7' r='2' fill='black'/%3E%3Cpath d='M10 7 h15' stroke='black' stroke-width='2'/%3E%3Ccircle cx='5' cy='15' r='2' fill='black'/%3E%3Cpath d='M10 15 h15' stroke='black' stroke-width='2'/%3E%3Ccircle cx='5' cy='23' r='2' fill='black'/%3E%3Cpath d='M10 23 h15' stroke='black' stroke-width='2'/%3E%3C/svg%3E");
+      }
+
     </style>
   </head>
 <body>
@@ -125,10 +146,9 @@ def generate_report_html(output_dir: str, genome_info: Dict[str, Any]) -> None:
             <table id="sortable-table">
                 <tr>
                     <th onclick="sortTable(0)">Sample ID</th>
-                    <th onclick="sortTable(1)">Description</th>
-                    <th onclick="sortTable(2)">Total size (bp)</th>
-                    <th onclick="sortTable(3)">Contigs</th>
-                    <th onclick="sortTable(4)">GC content</th>
+                    <th onclick="sortTable(1)">Total size (bp)</th>
+                    <th onclick="sortTable(2)">Contigs</th>
+                    <th onclick="sortTable(3)">GC content</th>
                     <th>Action</th>
                 </tr>
         """
@@ -137,7 +157,7 @@ def generate_report_html(output_dir: str, genome_info: Dict[str, Any]) -> None:
         # Create table rows based on the js and svg files
         for genome_code_name, info in genome_info.items():
             genome_name = info["Name"]
-            description = info["Description"]
+            # description = info["Description"]
             total_size = str(info["Total size"])
             number_of_contigs = str(info["Number of contigs"])
             gc_content = str(info["GC content"])
@@ -146,7 +166,6 @@ def generate_report_html(output_dir: str, genome_info: Dict[str, Any]) -> None:
                 f"""
                     <tr id='data/{genome_code_name}.js'>
                         <td>{genome_name}</td>
-                        <td>{description}</td>
                         <td>{total_size}</td>
                         <td>{number_of_contigs}</td>
                         <td>{gc_content}</td>
@@ -182,6 +201,7 @@ def generate_report_html(output_dir: str, genome_info: Dict[str, Any]) -> None:
             <div class='cgv-btn' id='btn-invert-colors' title='Invert Map Colors'></div>
             <div class='cgv-btn' id='btn-download' title='Download Map PNG'></div>
             <div class='cgv-btn' id='btn-toggle-labels' title='Toggle Labels'></div>
+            <div class='cgv-btn' id='btn-toggle-legend' title='Toggle Legend'></div>
             </div>
         </div>
         """
@@ -381,6 +401,12 @@ def generate_report_html(output_dir: str, genome_info: Dict[str, Any]) -> None:
             adjustTableHeight();
         };
 
+        // Toggle Labels (not included in the controls.js file)
+        onClick('btn-toggle-legend', () => {
+        cgv.legend.update({visible: !cgv.legend.visible});
+        cgv.draw();
+        });
+
     </script>
 </body>
 </html>"""
